| Title: | 'Amazon Web Services' Robotics Services |
|---|---|
| Description: | Interface to 'Amazon Web Services' robotics services, including the 'RobotMaker' API for developing, testing, and deploying intelligent robotics applications <https://aws.amazon.com/>. |
| Authors: | David Kretch [aut], Adam Banker [aut], Dyfan Jones [cre], Amazon.com, Inc. [cph] |
| Maintainer: | Dyfan Jones <[email protected]> |
| License: | Apache License (>= 2.0) |
| Version: | 0.8.0 |
| Built: | 2026-06-01 21:16:21 UTC |
| Source: | https://github.com/paws-r/paws |
This section provides documentation for the AWS RoboMaker API operations.
robomaker(config = list())robomaker(config = list())
config |
Optional configuration of credentials, endpoint, and/or region. |
A client for the service. You can call the service's operations using
syntax like svc$operation(...), where svc is the name you've assigned
to the client. The available operations are listed in the
Operations section.
svc <- robomaker(
config = list(
credentials = list(
creds = list(
access_key_id = "string",
secret_access_key = "string",
session_token = "string"
),
profile = "string"
),
endpoint = "string",
region = "string"
)
)
| batch_delete_worlds | Deletes one or more worlds in a batch operation |
| batch_describe_simulation_job | Describes one or more simulation jobs |
| cancel_deployment_job | Cancels the specified deployment job |
| cancel_simulation_job | Cancels the specified simulation job |
| cancel_simulation_job_batch | Cancels a simulation job batch |
| cancel_world_export_job | Cancels the specified export job |
| cancel_world_generation_job | Cancels the specified world generator job |
| create_deployment_job | Deploys a specific version of a robot application to robots in a fleet |
| create_fleet | Creates a fleet, a logical group of robots running the same robot application |
| create_robot | Creates a robot |
| create_robot_application | Creates a robot application |
| create_robot_application_version | Creates a version of a robot application |
| create_simulation_application | Creates a simulation application |
| create_simulation_application_version | Creates a simulation application with a specific revision id |
| create_simulation_job | Creates a simulation job |
| create_world_export_job | Creates a world export job |
| create_world_generation_job | Creates worlds using the specified template |
| create_world_template | Creates a world template |
| delete_fleet | Deletes a fleet |
| delete_robot | Deletes a robot |
| delete_robot_application | Deletes a robot application |
| delete_simulation_application | Deletes a simulation application |
| delete_world_template | Deletes a world template |
| deregister_robot | Deregisters a robot |
| describe_deployment_job | Describes a deployment job |
| describe_fleet | Describes a fleet |
| describe_robot | Describes a robot |
| describe_robot_application | Describes a robot application |
| describe_simulation_application | Describes a simulation application |
| describe_simulation_job | Describes a simulation job |
| describe_simulation_job_batch | Describes a simulation job batch |
| describe_world | Describes a world |
| describe_world_export_job | Describes a world export job |
| describe_world_generation_job | Describes a world generation job |
| describe_world_template | Describes a world template |
| get_world_template_body | Gets the world template body |
| list_deployment_jobs | Returns a list of deployment jobs for a fleet |
| list_fleets | Returns a list of fleets |
| list_robot_applications | Returns a list of robot application |
| list_robots | Returns a list of robots |
| list_simulation_applications | Returns a list of simulation applications |
| list_simulation_job_batches | Returns a list simulation job batches |
| list_simulation_jobs | Returns a list of simulation jobs |
| list_tags_for_resource | Lists all tags on a AWS RoboMaker resource |
| list_world_export_jobs | Lists world export jobs |
| list_world_generation_jobs | Lists world generator jobs |
| list_worlds | Lists worlds |
| list_world_templates | Lists world templates |
| register_robot | Registers a robot with a fleet |
| restart_simulation_job | Restarts a running simulation job |
| start_simulation_job_batch | Starts a new simulation job batch |
| sync_deployment_job | Syncrhonizes robots in a fleet to the latest deployment |
| tag_resource | Adds or edits tags for a AWS RoboMaker resource |
| untag_resource | Removes the specified tags from the specified AWS RoboMaker resource |
| update_robot_application | Updates a robot application |
| update_simulation_application | Updates a simulation application |
| update_world_template | Updates a world template |
## Not run: svc <- robomaker() svc$batch_delete_worlds( Foo = 123 ) ## End(Not run)## Not run: svc <- robomaker() svc$batch_delete_worlds( Foo = 123 ) ## End(Not run)